@@ -1,21 +1,18 @@
+from toxopy import trials_abv, fwarnings
 import pandas as pd
 from scipy.stats import mannwhitneyu
-from warnings import filterwarnings
 from os import remove
-from toxopy.recycle import trials
 
 
 def calc_dlc_mw(csv_file, export=False):
 
-    filterwarnings("ignore")
 
     df = pd.read_csv(csv_file)
 
-    tls = trials()
+    tls = trials_abv()
 
     variables = ['vel', 'distance', 'cat_distance', 'acceleration', 'moving']
 
-
     for t in tls:
 
         with open(t, 'w') as f:
@@ -23,7 +20,7 @@ def calc_dlc_mw(csv_file, export=False):
             if export is False:
 
                 print('\nTrial:', t, '\n')
-                
+
                 remove(t)
 
             else:
@@ -31,9 +28,11 @@ def calc_dlc_mw(csv_file, export=False):
 
             for j in variables:
 
-                pv = df[(df['status'] == 'positive') & (df['trial'] == t) & (df['var'] == j)]['value']
+                pv = df[(df['status'] == 'Positive') & (
+                    df['trial'] == t) & (df['var'] == j)]['value']
 
-                nv = df[(df['status'] == 'negative') & (df['trial'] == t) & (df['var'] == j)]['value']
+                nv = df[(df['status'] == 'Negative') & (
+                    df['trial'] == t) & (df['var'] == j)]['value']
 
                 stat, p = mannwhitneyu(pv, nv)
 
@@ -53,22 +52,22 @@ def calc_dlc_mw(csv_file, export=False):
 
                     else:
 
-                            if p > alpha:
+                        if p > alpha:
 
-                                print(t + ',' + j + ',' + str(stat) + ',' + str(p), file=f)
+                            print(f'{t},{j},{stat},{p}', file=f)
 
-                            elif p < alpha:
-                                print(t + ',' + j + ',' + str(stat) + ',' + str(p) + '*', file=f)
-
-        f.close()
+                        elif p < alpha:
+                            print(f'{t},{j},{stat},{p},*', file=f)
+                            
 
     if export is True:
 
         combined_csv = pd.concat([pd.read_csv(f) for f in tls])
 
         combined_csv.to_csv("mannwhitneyu_stats_results.csv",
-                        index=False,
-                        encoding='utf-8-sig')
-
+                            index=False,
+                            encoding='utf-8-sig')
 
         [remove(f) for f in tls]
+
+calc_dlc_mw("/Users/Felis.catus/Desktop/GitHub/bchaselab/DLC-Chaselab/Data/dlc_all_avgs_updated.csv", export=False)
\ No newline at end of file
